CHANGES
=======

0.4 (2024-03-03)
----------------

- **Removed**: Drop support for Python 3.4, 3.5, 3.6 and 3.7.

- Add support for Python 3.9, 3.10 and 3.11.

- Fix Flake8.

- Use GitHub Actions for CI.

- Make Python 3.11 the default testing environment.

- Upgrade PonyORM to 0.7.17.

- Show full diffs in the test output.

- Add Editors config and venv to .gitignore.

- Remove report to coveralls.

- Update pre-commit revs.


0.3 (2020-04-26)
----------------

- **Removed**: Removed support for Python 2.
  
  You have to upgrade to Python 3 if you want to use this version.

- Added support for Python 3.6, 3.7 and 3.8 and PyPy 3.6.

- Make Python 3.7 the default testing environment.

- Upgrade PonyORM to 0.7.13.

- Add integration for the Black code formatter.




0.2 (2017-07-20)
----------------

- Upgrade PonyORM to 0.7.2.
- Use a dictonary for passing parameters to db.bind in examples and tests.


0.1 (2017-04-22)
----------------

- Initial public release.
